//
// Written by Igor Tolmachev, IT Samples
//        mailto:support@itsamples.com
//
// Copyright (c) 2009.
//
// This code may be used in compiled form in any way you desire. This
// file may be redistributed unmodified by any means PROVIDING it is 
// not sold for profit without the authors written consent, and 
// providing that this notice and the authors name and all copyright 
// notices remains intact. If the source code in this file is used in 
// any  commercial application then a statement along the lines of 
// "Portions copyright (c) Igor Tolmachev, 2009" must be included in 
// the startup banner, "About" box or printed documentation. An email 
// letting me know that you are using it would be nice as well. That's 
// not much to ask considering the amount of work that went into this.
//
// This file is provided "as is" with no expressed or implied warranty.
// The author accepts no liability for any damage/loss of business that
// this product may cause.
//
// Expect bugs!
// 
// Please use and enjoy, and let me know of any bugs/mods/improvements 
// that you have found/implemented and I will fix/incorporate them into 
// this file. 

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Drawing.Imaging;
using System.Text;
using System.Windows.Forms;
using System.IO;
using System.Security.Permissions;

namespace HPIConverter
{
    public partial class MainForm : Form
    {
        private HPIHelper m_helper = new HPIHelper();

        public MainForm()
        {
            InitializeComponent();
        }

        private void OnButtonOpen(object sender, EventArgs e)
        {
            if (this.openFileDialog.ShowDialog().Equals(DialogResult.OK))
            {
                if (m_helper.LoadFile(openFileDialog.FileName))
                {
                    this.buttonSaveJpeg.Enabled = false;
                    this.buttonSavePng.Enabled = false;

                    Image image = m_helper.GetImage();
                    if (image != null)
                        this.pictureBox.Image = image;

                    if (m_helper.GetJpegImage() != null)
                    {
                        this.buttonSaveJpeg.Enabled = true;
                        this.saveJPEGMenuItem.Enabled = true;
                    }

                    if (m_helper.GetPngImage() != null)
                    {
                        this.buttonSavePng.Enabled = true;
                        this.savePNGMenuItem.Enabled = true;
                    }
                }
            }
        }

        private void OnSaveJpeg(object sender, EventArgs e)
        {
            this.saveFileDialog.Filter = "JPEG images (.jpg, .jpeg)|*.jp*";
            this.saveFileDialog.DefaultExt = "jpg";
            this.saveFileDialog.FileName = m_helper.GetFileName();
            if (this.saveFileDialog.ShowDialog().Equals(DialogResult.OK))
            {
                BinaryWriter binWriter = new BinaryWriter(File.Open(this.saveFileDialog.FileName, FileMode.OpenOrCreate));
                try
                {
                    binWriter.Write(m_helper.GetJpegBytes());
                }
                catch (Exception)
                {
                }
                finally
                {
                    binWriter.Close();
                }
            }
        }

        private void OnSavePng(object sender, EventArgs e)
        {
            this.saveFileDialog.Filter = "PNG images (.png)|*.png";
            this.saveFileDialog.DefaultExt = "png";
            this.saveFileDialog.FileName = m_helper.GetFileName();
            if (this.saveFileDialog.ShowDialog().Equals(DialogResult.OK))
            {
                BinaryWriter binWriter = new BinaryWriter(File.Open(this.saveFileDialog.FileName, FileMode.OpenOrCreate));
                try
                {
                    binWriter.Write(m_helper.GetPngBytes());
                }
                catch (Exception)
                {
                }
                finally
                {
                    binWriter.Close();
                }
            }
        }

        private void OnButtonConvert(object sender, EventArgs e)
        {
            ConvertForm formConvert = new ConvertForm();
            if (formConvert.ShowDialog(this).Equals(DialogResult.OK))
            {
            }
        }

        private void OnExit(object sender, EventArgs e)
        {
            this.Close();
        }

        private void OnHome(object sender, EventArgs e)
        {
            String strURL = "http://www.itsamples.com";
            try
            {
                System.Diagnostics.Process.Start(strURL);
            }
            catch (System.ComponentModel.Win32Exception noBrowser)
            {
                if (noBrowser.ErrorCode == -2147467259) MessageBox.Show(noBrowser.Message);
            }
            catch (System.Exception other)
            {
                MessageBox.Show(other.Message);
            }
        }

        private void OnAbout(object sender, EventArgs e)
        {
            AboutForm formAbout = new AboutForm();
            formAbout.ShowDialog(this);
        }
    }
}